# Generated by Django 1.10.4 on 2016-12-10 21:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0002_auto_20151216_0201"),
    ]

    operations = [
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="name",
            field=models.CharField(max_length=36, verbose_name="Name"),
        ),
    ]
