# Generated by Django 2.2.6 on 2019-10-21 00:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("teryt_tree", "0004_auto_20170712_2335"),
    ]

    operations = [
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="level",
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="lft",
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name="jednostkaadministracyjna",
            name="rght",
            field=models.PositiveIntegerField(editable=False),
        ),
    ]
